# libpythonpro-ts
Módulo para criação de projetos Curso Pytools

Link para o curso [Python Pro](https://python.pro.br/)

[![Build Status](https://travis-ci.org/thiagomsales/libpythonpro.svg?branch=main)](https://travis-ci.org/thiagomsales/libpythonpro)
[![Updates](https://pyup.io/repos/github/thiagomsales/libpythonpro/shield.svg)](https://pyup.io/repos/github/thiagomsales/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/thiagomsales/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/thiagomsales/libpythonpro/)

Suportada a versão 3 de Python

Para instalar: 

```Console
python3 -m venv .venv
source .venv/bin/activate
pip instal -r requirements-dev.txt
```
Para conferir a qualidade do código:

```console
flake8

```